"""MAID LSP - Language Server Protocol implementation for MAID methodology.

This package provides an LSP server for real-time validation of MAID manifests
in code editors and IDEs.
"""

__version__ = "0.2.0"

__all__: list[str] = []
